Plot enrichment results using -log10(FDR)
get_enrichment_plot.RdGenerates a dot plot of enrichment results for enrichResult, gseaResult,
or compareClusterResult objects (including those returned by
enrichMsigDB()). Points are sized by gene/set count and coloured by
-log10(FDR). For compareCluster results, the plot is faceted by cluster with
top terms selected per cluster.